Snapshots
=========

SokobanSnapshot
---------------

.. autoclass:: sokoenginepy.io.SokobanSnapshot
    :members:
    :show-inheritance:
    :special-members: __init__


HexobanSnapshot
---------------

.. autoclass:: sokoenginepy.io.HexobanSnapshot
    :members:
    :show-inheritance:
    :special-members: __init__


TriobanSnapshot
---------------

.. autoclass:: sokoenginepy.io.TriobanSnapshot
    :members:
    :show-inheritance:
    :special-members: __init__


OctobanSnapshot
---------------

.. autoclass:: sokoenginepy.io.OctobanSnapshot
    :members:
    :show-inheritance:
    :special-members: __init__


Snapshot
--------

.. autoclass:: sokoenginepy.io.Snapshot
    :members:
    :undoc-members:
    :member-order: bysource
